Crate p3_circle

Crate p3_circle 

p3-circle

A STARK framework over the unit circle of a finite field, following the Circle STARKs paper by Haböck, Levit and Papini. This enables Mersenne-31, which has no large two-adic multiplicative subgroup, to be used as a STARK field.

Key items:

  • CirclePcs — the p3_commit::Pcs instantiation over circle domains
  • CircleDomain, CircleEvaluations — circle-group evaluation domains and the circle FFT (cfft)
  • DEEP quotients and circle-specific FRI folding for the opening argument

Part of Plonky3, dual-licensed under MIT and Apache 2.0.

Structs

CfftPerm
CircleCommitPhaseMultiStep
All queries’ openings of one commit-phase codeword, sharing one proof.
CircleDomain
A twin-coset of the circle group on F. It has a power-of-two size and an arbitrary shift.
CircleEvaluations
CircleFriProof
CircleInputProof
CirclePcs
CirclePcsProof
CirclePeriodicEvaluator
Evaluates periodic polynomials for Circle STARKs.
Point
Affine representation of a point on the circle. x^2 + y^2 == 1

Enums

InputError

Functions

build_periodic_lde_table_circle
Build the compact periodic LDE table using the circle evaluator.
circle_basis

Type Aliases

CfftView