pub struct CircleDomain<F> { /* private fields */ }Expand description
A twin-coset of the circle group on F. It has a power-of-two size and an arbitrary shift.
X is generator, O is the first coset, goes counterclockwise
O X .
. .
. O <- start = shift
. . - (1,0)
O .
. .
. . OFor ordering reasons, the other half will start at gen / shift:
. X O <- start = gen/shift
. .
O .
. . - (1,0)
. O
. .
O . .The full domain is the interleaving of these two cosets
Implementations